<?php return array(
    'root' => array(
        'pretty_version' => 'dev-master',
        'version' => 'dev-master',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'reference' => '073a81b4179534729edb4be281783e8295ba5c7c',
        'name' => 'icinga/incubator',
        'dev' => true,
    ),
    'versions' => array(
        'clue/block-react' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.4.0',
            ),
        ),
        'clue/buzz-react' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v2.7.0',
            ),
        ),
        'clue/connection-manager-extra' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.1.0',
            ),
        ),
        'clue/http-proxy-react' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.5.0',
            ),
        ),
        'clue/mq-react' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.2.0',
            ),
        ),
        'clue/redis-protocol' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v0.3.1',
            ),
        ),
        'clue/redis-react' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v2.3.0',
            ),
        ),
        'clue/soap-react' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.0.0',
            ),
        ),
        'clue/socket-raw' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.4.1',
            ),
        ),
        'clue/socks-react' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.1.0',
            ),
        ),
        'clue/stdio-react' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v2.3.0',
            ),
        ),
        'clue/term-react' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.2.0',
            ),
        ),
        'clue/utf8-react' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.1.0',
            ),
        ),
        'evenement/evenement' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v2.1.0',
            ),
        ),
        'gipfl/calendar' => array(
            'pretty_version' => 'v0.2.0',
            'version' => '0.2.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/calendar',
            'aliases' => array(),
            'reference' => 'a8b24f375c36fb8bb70034423c70299d07bddc81',
            'dev_requirement' => false,
        ),
        'gipfl/cli' => array(
            'pretty_version' => 'v0.5.1',
            'version' => '0.5.1.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/cli',
            'aliases' => array(),
            'reference' => '9fc6f25598f208c1bafaa4b9ee87d0465fdf2452',
            'dev_requirement' => false,
        ),
        'gipfl/curl' => array(
            'pretty_version' => 'v0.2.0',
            'version' => '0.2.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/curl',
            'aliases' => array(),
            'reference' => '20459fd8c68d86e3df30eb76f1938cc72c25d4fa',
            'dev_requirement' => false,
        ),
        'gipfl/data-type' => array(
            'pretty_version' => 'v0.3.0',
            'version' => '0.3.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/data-type',
            'aliases' => array(),
            'reference' => 'eb81eaeef93adb15c6c5522154516eae0e2a8e48',
            'dev_requirement' => false,
        ),
        'gipfl/db-migration' => array(
            'pretty_version' => 'v0.1.1',
            'version' => '0.1.1.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/db-migration',
            'aliases' => array(),
            'reference' => '12be94b0c83a5e018c9d3d42fe8e98b4cbe248ee',
            'dev_requirement' => false,
        ),
        'gipfl/diff' => array(
            'pretty_version' => 'v0.3.0',
            'version' => '0.3.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/diff',
            'aliases' => array(),
            'reference' => 'f9decb9cf20735d6cbe6f508aafd8a720922804b',
            'dev_requirement' => false,
        ),
        'gipfl/format' => array(
            'pretty_version' => 'v0.3.0',
            'version' => '0.3.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/format',
            'aliases' => array(),
            'reference' => 'b777cd55d4a02312b1ec115231e54729a91dcc25',
            'dev_requirement' => false,
        ),
        'gipfl/icinga-bundles' => array(
            'pretty_version' => 'v0.7.0',
            'version' => '0.7.0.0',
            'type' => 'metapackage',
            'install_path' => NULL,
            'aliases' => array(),
            'reference' => 'd28e12218c07174795e07d7ad235d3fac2a6be53',
            'dev_requirement' => false,
        ),
        'gipfl/icinga-cli-daemon' => array(
            'pretty_version' => 'v0.3.2',
            'version' => '0.3.2.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/icinga-cli-daemon',
            'aliases' => array(),
            'reference' => '19e1b203108fda37de39488fd8ff7ea392a42f03',
            'dev_requirement' => false,
        ),
        'gipfl/icingaweb2' => array(
            'pretty_version' => 'v0.9.0',
            'version' => '0.9.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/icingaweb2',
            'aliases' => array(),
            'reference' => 'afcafce316faa27483ea9333bebf2636f0ba27ad',
            'dev_requirement' => false,
        ),
        'gipfl/influxdb' => array(
            'pretty_version' => 'v0.4.0',
            'version' => '0.4.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/influxdb',
            'aliases' => array(),
            'reference' => '308cfe528ae7632bce5506956d7dfbad4e4e8d19',
            'dev_requirement' => false,
        ),
        'gipfl/json' => array(
            'pretty_version' => 'v0.2.0',
            'version' => '0.2.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/json',
            'aliases' => array(),
            'reference' => '5635790a19150beeece9edc67e82ecddc52ff4fb',
            'dev_requirement' => false,
        ),
        'gipfl/linux-health' => array(
            'pretty_version' => 'v0.2.0',
            'version' => '0.2.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/linux-health',
            'aliases' => array(),
            'reference' => '4d212535565f353f88c9eef3ecb54e20c40b8b37',
            'dev_requirement' => false,
        ),
        'gipfl/log' => array(
            'pretty_version' => 'v0.7.0',
            'version' => '0.7.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/log',
            'aliases' => array(),
            'reference' => 'df770bdc9c09b0428831345af7ce7d45a0c3a1bb',
            'dev_requirement' => false,
        ),
        'gipfl/openrpc' => array(
            'pretty_version' => 'v0.2.1',
            'version' => '0.2.1.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/openrpc',
            'aliases' => array(),
            'reference' => 'a29b8da2cdaf7d757d86aa0fe6d719cf68fb95ad',
            'dev_requirement' => false,
        ),
        'gipfl/process' => array(
            'pretty_version' => 'v0.3.0',
            'version' => '0.3.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/process',
            'aliases' => array(),
            'reference' => '22cae0a5791d7760e5defa28c7f7360f3bf78db3',
            'dev_requirement' => false,
        ),
        'gipfl/protocol' => array(
            'pretty_version' => 'v0.2.0',
            'version' => '0.2.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/protocol',
            'aliases' => array(),
            'reference' => 'bf1a0e160fe6f74c6be60be569c466d57551e73d',
            'dev_requirement' => false,
        ),
        'gipfl/protocol-jsonrpc' => array(
            'pretty_version' => 'v0.10.0',
            'version' => '0.10.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/protocol-jsonrpc',
            'aliases' => array(),
            'reference' => '12a8ada5f7d102288aad6e2a0139663d26ed66ad',
            'dev_requirement' => false,
        ),
        'gipfl/protocol-netstring' => array(
            'pretty_version' => 'v0.1.1',
            'version' => '0.1.1.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/protocol-netstring',
            'aliases' => array(),
            'reference' => 'c0021ea9d69883760ac176121041a05c9a51ca11',
            'dev_requirement' => false,
        ),
        'gipfl/react-utils' => array(
            'pretty_version' => 'v0.3.0',
            'version' => '0.3.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/react-utils',
            'aliases' => array(),
            'reference' => '37ff2daa4bcc36aced4cc9df5198caad519d7bdb',
            'dev_requirement' => false,
        ),
        'gipfl/simple-daemon' => array(
            'pretty_version' => 'v0.5.1',
            'version' => '0.5.1.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/simple-daemon',
            'aliases' => array(),
            'reference' => '67d9265d19284141fd8166bf6c412394a14e72c7',
            'dev_requirement' => false,
        ),
        'gipfl/socket' => array(
            'pretty_version' => 'v0.4.0',
            'version' => '0.4.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/socket',
            'aliases' => array(),
            'reference' => '1a2c78709e0bcf7de2469860fbfa807a4bcee555',
            'dev_requirement' => false,
        ),
        'gipfl/stream' => array(
            'pretty_version' => 'v0.2.0',
            'version' => '0.2.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/stream',
            'aliases' => array(),
            'reference' => 'ae0f8f4fd47a6dcc57885b232e239b0ba82889a3',
            'dev_requirement' => false,
        ),
        'gipfl/systemd' => array(
            'pretty_version' => 'v0.3.0',
            'version' => '0.3.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/systemd',
            'aliases' => array(),
            'reference' => 'ccfabb352a9ea9fd33d4cb426bc3793a651bf466',
            'dev_requirement' => false,
        ),
        'gipfl/translation' => array(
            'pretty_version' => 'v0.1.1',
            'version' => '0.1.1.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/translation',
            'aliases' => array(),
            'reference' => 'e974e6a2f0b524678b6554ee0046b5dd5f70a25d',
            'dev_requirement' => false,
        ),
        'gipfl/web' => array(
            'pretty_version' => 'v0.11.0',
            'version' => '0.11.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/web',
            'aliases' => array(),
            'reference' => 'd331fe195f7bab08561ee015ba56edeb334a1533',
            'dev_requirement' => false,
        ),
        'gipfl/zfdb' => array(
            'pretty_version' => 'v0.4.0',
            'version' => '0.4.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/zfdb',
            'aliases' => array(),
            'reference' => 'beb7ceabc80e8c81f0e237afcfb064a67e1432d6',
            'dev_requirement' => false,
        ),
        'gipfl/zfdbstore' => array(
            'pretty_version' => '0.2.2',
            'version' => '0.2.2.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gipfl/zfdbstore',
            'aliases' => array(),
            'reference' => '1fa1f7ea2a24a0536681923a30f8ccb4e2a3b377',
            'dev_requirement' => false,
        ),
        'guzzlehttp/psr7' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '1.6.1',
            ),
        ),
        'icinga/incubator' => array(
            'pretty_version' => 'dev-master',
            'version' => 'dev-master',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'reference' => '073a81b4179534729edb4be281783e8295ba5c7c',
            'dev_requirement' => false,
        ),
        'ipl/html' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v0.3.0',
            ),
        ),
        'ipl/orm' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v0.1.0',
            ),
        ),
        'ipl/sql' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v0.1.0',
            ),
        ),
        'ipl/stdlib' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v0.5.0',
            ),
        ),
        'ipl/validator' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v0.1.0',
            ),
        ),
        'ipl/web' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v0.1.0',
            ),
        ),
        'paragonie/random_compat' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v2.0.18',
            ),
        ),
        'predis/predis' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.1.6',
            ),
        ),
        'psr/http-message' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '1.0.1',
            ),
        ),
        'psr/log' => array(
            'pretty_version' => '1.1.4',
            'version' => '1.1.4.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'reference' => 'd49695b909c3b7628b6289db5479a1c204601f11',
            'dev_requirement' => false,
        ),
        'ralouphie/getallheaders' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '3.0.3',
            ),
        ),
        'ramsey/uuid' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '3.9.3',
            ),
        ),
        'react/cache' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.1.0',
            ),
        ),
        'react/child-process' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v0.6.1',
            ),
        ),
        'react/datagram' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.5.0',
            ),
        ),
        'react/dns' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.4.0',
            ),
        ),
        'react/event-loop' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.1.1',
            ),
        ),
        'react/http' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.1.0',
            ),
        ),
        'react/http-client' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v0.5.10',
            ),
        ),
        'react/promise' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v2.8.0',
            ),
        ),
        'react/promise-stream' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.2.0',
            ),
        ),
        'react/promise-timer' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.6.0',
            ),
        ),
        'react/socket' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.6.0',
            ),
        ),
        'react/stream' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.1.1',
            ),
        ),
        'ringcentral/psr7' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '1.3.0',
            ),
        ),
        'symfony/polyfill-ctype' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.18.1',
            ),
        ),
    ),
);
